/*
 * Copyright (C) 2004 Jimmy Do <crispyleaves@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "manage-presets-window.h"
#include "add-profile-dialog.h"
#include "profile-manager.h"
#include "timer-applet.h"

static void
on_profile_added (GtkWidget *profile_manager, gchar *profile_name, gdouble profile_duration, gpointer user_data)
{
	GtkTreeRowReference *new_row_ref;
	new_row_ref = timer_applet_add_preset (profile_name, profile_duration);
	profile_manager_select_row (profile_manager, new_row_ref);
}

static void
on_profile_edited (GtkWidget *profile_manager, GtkTreeRowReference *row_ref, gchar *profile_name, gdouble profile_duration, gpointer user_data)
{
	timer_applet_update_preset (row_ref, profile_name, profile_duration);
	
	profile_manager_select_row (profile_manager, row_ref);
}

static void
on_profile_deleted (GtkWidget *profile_manager, GtkTreeRowReference *row_ref, gpointer user_data)
{
	timer_applet_remove_preset (row_ref);
}

GtkWidget *
manage_presets_window_new (void)
{
	GtkWidget *manage_profiles_window;
	GtkWidget *vbox;
	GtkWidget *label;
	GtkWidget *profile_manager_widget;
	
	manage_profiles_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
	g_object_set (G_OBJECT (manage_profiles_window), "border-width", 12,
				"title", _("Manage Presets"), NULL);
	
	vbox = gtk_vbox_new (FALSE, 6);
	label = gtk_label_new (_("Timer Presets:"));
	profile_manager_widget = profile_manager_new (GTK_TREE_MODEL (timer_applet_get_presets_list ()));
	g_object_set (G_OBJECT (label), "xalign", 0.0, NULL);
							  
	profile_manager_set_profile_handlers (profile_manager_widget, on_profile_added, NULL, on_profile_edited, NULL, on_profile_deleted, NULL);
	
	
	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
	gtk_box_pack_start (GTK_BOX (vbox), profile_manager_widget, TRUE, TRUE, 0);
	gtk_container_add (GTK_CONTAINER (manage_profiles_window), vbox);
	gtk_widget_show (label);
	gtk_widget_show (profile_manager_widget);
	gtk_widget_show (vbox);
	
	g_signal_connect (G_OBJECT (manage_profiles_window), "delete-event", G_CALLBACK (gtk_widget_hide_on_delete), NULL);

	return manage_profiles_window;
}

void
manage_presets_window_open (GtkWindow *manage_presets_window)
{
	g_assert (manage_presets_window);
	gtk_window_present (GTK_WINDOW (manage_presets_window));
}
